%% Static model without labor
% this code plots the relation between aggregate output and interest rate control (\phi)
% replicates Figure 2
% the distribution is assumed to be log-normal with mean (mu) and std (sig)
% SOE and POE share the same distribution
% 2015/10/30
clear all
%% Parameters
zs   = .01; % aggregate component of productivity in SOE sector
zp   = .02; % aggregate component of productivity in POE sector
Ee   = 1;   % mean of lognormal distribution
sig  = .3;  % standard deviation of log-normal distribution
b    = 2;   % SOE has greater borrowing capacity
tau  = 2;   % subsidy parameter for SOE
mu   = .5;  % measure of SOE
theta_vec = .3;             % consider three different values of \theta
phi_vec   = 0:.0005:.01;    % vector of values of \phi
rini      = .02;            % initial guess of equilibrium interest rate
%% start to compute output in two policy regimes: before and after liberalization
for jj = 1:length(theta_vec)
    theta = theta_vec(jj);
    for j=1:length(phi_vec)
        phi0 = phi_vec(j);
        ParaSet0 =[zs zp sig b tau mu theta phi0 Ee]';
        rlow = 0;  rupp = .2; 
        % solve equilibrium interest rate and output
        [r0, fval] = fminsearchbnd(@(x)Fun_SolveR(x,ParaSet0),rini,rlow,rupp,optimset('TolX',1e-12,'Display','off'));
        [Ys,Yp,Y,Ks,Kp,As,Ap,ep_l,es_l]=Fun_SolveY(r0,ParaSet0);
        Yvec_ctrl(jj,j) =Y;
    end
end
%% plot relationship between aggregate output and phi
figure(1)
for jj=1:length(theta_vec)
    plot(phi_vec,Yvec_ctrl(jj,:),'color',[.2 .2 .2],'LineWidth',3);hold on
end

ylabel('Aggregate Output')
xlabel('Interest Rate Control (\phi)')